yt.geometry.particle\_oct\_container module
===========================================

.. automodule:: yt.geometry.particle_oct_container
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
